Learn R Programming

rxode2parse (version 2.0.18)

.udfEnvReset: Lock/Unlock environment for getting R user functions

Description

Lock/Unlock environment for getting R user functions

Usage

.udfEnvReset(lock = TRUE)

Value

lock status

Arguments

lock

logical to see if environment to look for user defined functions is locked. If it is locked then environments are not assigned. When NULL returns lock status

Author

Matthew L. Fidler